@@ -3,8 +3,10 @@ use strict;
 use warnings;
 use Cwd;
 use Carp ();
+use Module::CPANfile::Environment ();
+use Module::CPANfile::Result;
 
-our $VERSION = '0.9033';
+our $VERSION = '0.9034';
 
 sub new {
     my($class, $file) = @_;
@@ -154,155 +156,6 @@ sub _dump_prereqs {
     $code;
 }
 
-package Module::CPANfile::Environment;
-use strict;
-use Carp ();
-
-my @bindings = qw(
-    on requires recommends suggests conflicts
-    feature
-    osname
-    configure_requires build_requires test_requires author_requires
-);
-
-my $file_id = 1;
-
-sub import {
-    my($class, $result_ref) = @_;
-    my $pkg = caller;
-
-    $$result_ref = Module::CPANfile::Result->new;
-    for my $binding (@bindings) {
-        no strict 'refs';
-        *{"$pkg\::$binding"} = sub { $$result_ref->$binding(@_) };
-    }
-}
-
-sub parse {
-    my $file = shift;
-
-    my $code = do {
-        open my $fh, "<", $file or die "$file: $!";
-        join '', <$fh>;
-    };
-
-    my($res, $err);
-
-    {
-        local $@;
-        $res = eval sprintf <<EVAL, $file_id++;
-package Module::CPANfile::Sandbox%d;
-no warnings;
-my \$_result;
-BEGIN { import Module::CPANfile::Environment \\\$_result };
-
-# line 1 "$file"
-$code;
-
-\$_result;
-EVAL
-        $err = $@;
-    }
-
-    if ($err) { die "Parsing $file failed: $err" };
-
-    return $res;
-}
-
-package Module::CPANfile::Result;
-use strict;
-
-sub from_prereqs {
-    my($class, $spec) = @_;
-    bless {
-        phase => 'runtime',
-        spec => $spec,
-    }, $class;
-}
-
-sub new {
-    bless {
-        phase => 'runtime', # default phase
-        features => {},
-        feature => undef,
-        spec  => {},
-    }, shift;
-}
-
-sub on {
-    my($self, $phase, $code) = @_;
-    local $self->{phase} = $phase;
-    $code->()
-}
-
-sub feature {
-    my($self, $identifier, $description, $code) = @_;
-
-    # shortcut: feature identifier => sub { ... }
-    if (@_ == 3 && ref($description) eq 'CODE') {
-        $code = $description;
-        $description = $identifier;
-    }
-
-    unless (ref $description eq '' && ref $code eq 'CODE') {
-        Carp::croak("Usage: feature 'identifier', 'Description' => sub { ... }");
-    }
-
-    local $self->{feature} = $self->{features}{$identifier}
-      = { identifier => $identifier, description => $description, spec => {} };
-    $code->();
-}
-
-sub osname { die "TODO" }
-
-sub requires {
-    my($self, $module, $requirement) = @_;
-    ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{requires}{$module} = $requirement || 0;
-}
-
-sub recommends {
-    my($self, $module, $requirement) = @_;
-    ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{recommends}{$module} = $requirement || 0;
-}
-
-sub suggests {
-    my($self, $module, $requirement) = @_;
-    ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{suggests}{$module} = $requirement || 0;
-}
-
-sub conflicts {
-    my($self, $module, $requirement) = @_;
-    ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{conflicts}{$module} = $requirement || 0;
-}
-
-# Module::Install compatible shortcuts
-
-sub configure_requires {
-    my($self, @args) = @_;
-    $self->on(configure => sub { $self->requires(@args) });
-}
-
-sub build_requires {
-    my($self, @args) = @_;
-    $self->on(build => sub { $self->requires(@args) });
-}
-
-sub test_requires {
-    my($self, @args) = @_;
-    $self->on(test => sub { $self->requires(@args) });
-}
-
-sub author_requires {
-    my($self, @args) = @_;
-    $self->on(develop => sub { $self->requires(@args) });
-}
-
-package Module::CPANfile;
-
 1;
 
 __END__
